#ifndef PROCJACOBISVD_SEEN
#define PROCJACOBISVD_SEEN

#include "FragCds.h"

double
ProcJacobiSVD(const Cds *cds1, const Cds *cds2, double **rotmat,
              const double *weights,
              double **Rmat, double **Umat, double **VTmat, double *sigma);

double
ProcJacobiSVDvan(const Cds *cds1, const Cds *cds2, double **rotmat,
                 double **Rmat, double **Umat, double **VTmat, double *sigma);

double
ProcJacobiSVDCov(Cds *cds1, Cds *cds2, double **rotmat,
                 const double **covmat,
                 double **Rmat, double **Umat, double **VTmat,
                 double *sigma);

double
ProcJacobiSVDFrag(const FragCds *cds1, const FragCds *cds2, double **rotmat,
                  double **Rmat, double **Umat, double **VTmat, double *sigma);

#endif
